@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : ipv6calc.c
- * Version    : $Id: ipv6calc.c,v 1.13 2002/11/12 19:03:29 peter Exp $
- * Copyright  : 2001-2002 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: ipv6calc.c,v 1.18 2003/08/28 18:51:55 peter Exp $
+ * Copyright  : 2001-2003 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Central program (main)
@@ -521,6 +521,18 @@ int main(int argc,char *argv[]) {
 			retval = addr_to_ipv4addrstruct(argv[0], resultstring, &ipv4addr);
 			argc--;
 			break;
+			
+		case FORMAT_ipv4hex:
+			if (argc < 1) { printhelp_missinginputdata(); exit(EXIT_FAILURE); };
+			retval = addrhex_to_ipv4addrstruct(argv[0], resultstring, &ipv4addr, 0);
+			argc--;
+			break;
+
+		case FORMAT_ipv4revhex:
+			if (argc < 1) { printhelp_missinginputdata(); exit(EXIT_FAILURE); };
+			retval = addrhex_to_ipv4addrstruct(argv[0], resultstring, &ipv4addr, 1);
+			argc--;
+			break;
 
 		case FORMAT_base85:
 			if (argc < 1) { printhelp_missinginputdata(); exit(EXIT_FAILURE); };
@@ -730,6 +742,8 @@ int main(int argc,char *argv[]) {
 			formatoptions |= FORMATOPTION_printfulluncompressed;
 		} else if ( (inputtype == FORMAT_ipv6addr) && (action == ACTION_undefined) ) {
 			outputtype = FORMAT_ipv6addr;
+		} else if ( ((inputtype == FORMAT_ipv4addr) || (inputtype == FORMAT_ipv4hex) || (inputtype == FORMAT_ipv4revhex)) && (action == ACTION_undefined) ) {
+			outputtype = FORMAT_ipv4addr;
 		};
 
 		if ( outputtype != FORMAT_undefined ) {
@@ -890,6 +904,11 @@ int main(int argc,char *argv[]) {
 			};
 			retval = librfc2874_addr_to_bitstring(&ipv6addr, resultstring, formatoptions);
 			break;
+			
+		case FORMAT_octal:
+			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE); };
+			retval = libipv6addr_to_octal(&ipv6addr, resultstring, formatoptions);
+			break;
 				
 		case FORMAT_revnibbles_int:
 		case FORMAT_revnibbles_arpa:
@@ -922,7 +941,7 @@ int main(int argc,char *argv[]) {
 
 		case FORMAT_ipv6addr:
 			if (ipv6addr.flag_valid != 1) { fprintf(stderr, "No valid IPv6 address given!\n"); exit(EXIT_FAILURE); };
-			if ((formatoptions & (FORMATOPTION_printuncompressed | FORMATOPTION_printfulluncompressed)) != 0) {
+			if ((formatoptions & (FORMATOPTION_printuncompressed | FORMATOPTION_printfulluncompressed | FORMATOPTION_printprefix | FORMATOPTION_printsuffix)) != 0) {
 				retval = libipv6addr_ipv6addrstruct_to_uncompaddr(&ipv6addr, resultstring, formatoptions);
 			} else {
 				retval = librfc1884_ipv6addrstruct_to_compaddr(&ipv6addr, resultstring, formatoptions);
